@@ -36,7 +36,7 @@ class CassettePolling(threading.Thread):
         self.qrcode_que = NonBlockQue()
         self.qrPollingStamp=0
         self.manual_sequence = MANUAL_OPERATION_START
-        self.prevMode=None
+        self.prevMode=''
         self.prevCassetteStatus=None
     def stopTakePhotoProcedure(self):
         if self.takePhotoProcedure != None and self.takePhotoProcedure.is_alive():
@@ -109,8 +109,8 @@ class CassettePolling(threading.Thread):
         try:
             status = DEVICE_STATE_CASSETTE_QR
             qr = None
-            if self.slotIndex ==0:
-                print('slot', self.slotIndex, 'Operation',self.manual_sequence)
+#             if self.slotIndex ==0:
+#                 print('manual slot', self.slotIndex, 'Operation',self.manual_sequence)
                 
             if self.cassetteOut() and self.manual_sequence != MANUAL_OPERATION_TEST:
                 setOperation(self.slotIndex, MANUAL_OPERATION_START)
@@ -167,8 +167,8 @@ class CassettePolling(threading.Thread):
 
     def autoQr(self):
         try:
-            if self.slotIndex ==0:
-                print('slot', self.slotIndex, 'Operation',self.manual_sequence)
+#             if self.slotIndex ==0:
+#                 print('auto slot', self.slotIndex, 'Operation',self.manual_sequence)
             qrCode=''
             status=DEVICE_STATE_CASSETTE_EMPTY
             for i in range(7):                
@@ -209,13 +209,14 @@ class CassettePolling(threading.Thread):
         
     def getQr(self):
         currentMode=getDetectionMode()
-        if self.prevMode!=None and self.prevMode!=currentMode:
+        if self.prevMode!='' and self.prevMode!=currentMode:
             print('mode changed')
             self.stopTakePhotoProcedure()
         self.prevMode=currentMode
         if currentMode == CASSETTE_DETECTION_MODE_AUTO:
             return self.autoQr()
-        return self.manualQr()
+        else:
+            return self.manualQr()
     
 
 ##self.notifyQue.put([self.slotNo, int(parsing[RSLT][RCODE]), self.cassetteId, parsing[RSLT][MSSG], recordId[self.slotNo]])
